@@ -99,7 +99,7 @@ tidy_multi_dist_autoplot <- function(.data, .plot_type = "density", .line_size =
         "tidy_pareto_single_parameter", "tidy_pareto", "tidy_inverse_pareto",
         "tidy_generalized_pareto","tidy_paralogistic", "tidy_inverse_exponential",
         "tidy_inverse_gamma","tidy_inverse_weibull","tidy_burr","tidy_inverse_burr",
-        "tidy_inverse_gaussian","tidy_generalized_beta"
+        "tidy_inverse_gaussian","tidy_generalized_beta","tidy_t"
     )) {
         rlang::abort("The data passed must come from a `tidy_` distribution function.")
     }
@@ -137,7 +137,7 @@ tidy_multi_dist_autoplot <- function(.data, .plot_type = "density", .line_size =
             paste0("Mean Log: ", toString(atb$.param_list$.meanlog), " - SD Log: ", toString(atb$.param_list$.sdlog))
         } else if (atb$all$tibble_type == "tidy_cauchy") {
             paste0("Location: ", toString(atb$.param_list$.location), " - Scale: ", toString(atb$.param_list$.scale))
-        } else if (atb$all$tibble_type == "tidy_chisquare") {
+        } else if (atb$all$tibble_type %in% c("tidy_chisquare","tidy_t")) {
             paste0("DF: ", toString(atb$.param_list$.df), " - NPC: ", toString(atb$.param_list$.ncp))
         } else if (atb$all$tibble_type == "tidy_weibull") {
             paste0("Shape: ", toString(atb$.param_list$.schape), " - Scale: ", toString(atb$.param_list$.scale))
@@ -223,7 +223,7 @@ tidy_multi_dist_autoplot <- function(.data, .plot_type = "density", .line_size =
     } else if (plot_type == "density" & atb$all$distribution_family_type == "discrete"){
         plt <- data_tbl %>%
             ggplot2::ggplot(
-                ggplot2::aes(x = y, group = interaction(dist_name, sim_number), color = dist_name)
+                ggplot2::aes(x = y, group = interaction(dist_name, sim_number), fill = dist_name)
             ) +
             ggplot2::geom_histogram(
                 alpha = 0.318, color = "#e9ecef", bins = max(unique(data_tbl$y)) + 1,
@@ -237,16 +237,24 @@ tidy_multi_dist_autoplot <- function(.data, .plot_type = "density", .line_size =
             ) +
             ggplot2::theme(legend.position = leg_pos)
     } else if (plot_type == "quantile") {
+        ## EDIT
+        data_tbl <- data_tbl %>%
+            dplyr::select(sim_number, q) %>%
+            dplyr::group_by(sim_number) %>%
+            dplyr::arrange(q) %>%
+            dplyr::mutate(x = 1:dplyr::n()) %>%
+            dplyr::ungroup()
+        ## End EDIT
         plt <- data_tbl %>%
             ggplot2::ggplot(
                 ggplot2::aes(
-                    x = qs, y = q, group = interaction(dist_name, sim_number), color = dist_name
+                    x = x, y = q, group = interaction(dist_name, sim_number), color = dist_name
                 )
             ) +
             ggplot2::geom_line(size = line_size) +
             ggplot2::theme_minimal() +
             ggplot2::labs(
-                title = "Qantile Plot",
+                title = "Quantile Plot",
                 subtitle = sub_title,
                 color = "Simulation"
             ) +
@@ -255,13 +263,13 @@ tidy_multi_dist_autoplot <- function(.data, .plot_type = "density", .line_size =
         plt <- data_tbl %>%
             ggplot2::ggplot(
                 ggplot2::aes(
-                    x = ps, y = p, group = interaction(dist_name, sim_number), color = dist_name
+                    x = y, group = interaction(dist_name, sim_number), color = dist_name
                 )
             ) +
-            ggplot2::geom_line(size = line_size) +
+            ggplot2::stat_ecdf(size = line_size) +
             ggplot2::theme_minimal() +
             ggplot2::labs(
-                title = "Probabilty Plot",
+                title = "Probability Plot",
                 subtitle = sub_title,
                 color = "Simulation"
             ) +
@@ -306,7 +314,7 @@ tidy_multi_dist_autoplot <- function(.data, .plot_type = "density", .line_size =
                 color = "black",
                 linetype = "dashed"
             ) +
-            ggplot2::xlim(0, max_dy)
+            ggplot2::ylim(0, max_dy)
     }
 
     if (.geom_jitter) {
