@@ -84,7 +84,7 @@ tidy_zero_truncated_geometric <- function(.n = 50, .prob = 1, .num_sims = 1) {
       purrr::set_names("dx", "dy") %>%
       dplyr::as_tibble())) %>%
     dplyr::mutate(p = list(actuar::pztgeom(ps, prob = prob))) %>%
-    dplyr::mutate(q = list(actuar::qztgeom(qs, prob = prob))) %>%
+    dplyr::mutate(q = list(actuar::qztgeom(tidy_scale_zero_one_vec(unlist(y)), prob = prob))) %>%
     tidyr::unnest(cols = c(x, y, d, p, q)) %>%
     dplyr::ungroup()
 
